@@ -7,7 +7,7 @@ import (
 	"os/exec"
 	"strings"
 
-	"github.com/twpayne/chezmoi/v2/internal/chezmoilog"
+	"github.com/twpayne/chezmoi/internal/chezmoilog"
 )
 
 type bitwardenSecretsConfig struct {
@@ -25,14 +25,9 @@ func (c *Config) bitwardenSecretsTemplateFunc(secretID string, additionalArgs ..
 	default:
 		panic(fmt.Errorf("expected 1 or 2 arguments, got %d", len(additionalArgs)+1))
 	}
-	output, err := c.bitwardenSecretsOutput(args)
-	if err != nil {
-		panic(err)
-	}
+	output := mustValue(c.bitwardenSecretsOutput(args))
 	var data map[string]any
-	if err := json.Unmarshal(output, &data); err != nil {
-		panic(newParseCmdOutputError(c.BitwardenSecrets.Command, args, output, err))
-	}
+	must(json.Unmarshal(output, &data))
 	return data
 }
 
